pub struct MessageSchedule<F: Field, Adder> {
msg_schedule: Vec<MessageScheduleState<F, Adder>>,
_phantom: PhantomData<F>,
}Expand description
Represents the 64 rounds of message schedule. Each Round consists of 32 Wires where the first 16 rounds are identity gates, and the rest are computed as per the spec
Fields
msg_schedule: Vec<MessageScheduleState<F, Adder>>_phantom: PhantomData<F>Implementations
Sourceimpl<F, Adder> MessageSchedule<F, Adder>
impl<F, Adder> MessageSchedule<F, Adder>
Sourcepub fn new(
ckt_builder: &mut CircuitBuilder<F>,
carry_layer: Option<&InputLayerNodeRef<F>>,
msg_vars: &[NodeRef<F>],
) -> Self
pub fn new( ckt_builder: &mut CircuitBuilder<F>, carry_layer: Option<&InputLayerNodeRef<F>>, msg_vars: &[NodeRef<F>], ) -> Self
Given the 16, 32-bit inputs in MBS format, computes the 64
rounds of message schedule corresponding to the input. The
msg_vars must be the 16 32-bit words decomposed in MBS format.
Sourcepub fn get_output_nodes(&self) -> Vec<NodeRef<F>>
pub fn get_output_nodes(&self) -> Vec<NodeRef<F>>
Returns the list of 64 nodes corresponding to SHA256 message schedule
Sourcepub fn populate_message_schedule(
&self,
circuit: &mut Circuit<F>,
input_data: &[u32],
) -> Vec<u32>
pub fn populate_message_schedule( &self, circuit: &mut Circuit<F>, input_data: &[u32], ) -> Vec<u32>
Attaches a message schedule to the SHA Circuit. Note that this needs to match the way adder is implemented
Sourcepub fn get_output_expr(&self) -> AbstractExpression<F>
pub fn get_output_expr(&self) -> AbstractExpression<F>
Creates the output expression that can be tested with other output expressions